==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/outputs/DataQualityJobDefinitionDataQualityBaselineConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property constraintsResource The constraints resource for a monitoring job. Fields are documented below.
 * @property statisticsResource The statistics resource for a monitoring job. Fields are documented below.
 */
public data class DataQualityJobDefinitionDataQualityBaselineConfig(
    public val constraintsResource:
    DataQualityJobDefinitionDataQualityBaselineConfigConstraintsResource? = null,
    public val statisticsResource:
    DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResource? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.sagemaker.outputs.DataQualityJobDefinitionDataQualityBaselineConfig):
            DataQualityJobDefinitionDataQualityBaselineConfig =
            DataQualityJobDefinitionDataQualityBaselineConfig(
                constraintsResource = javaType.constraintsResource().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.sagemaker.kotlin.outputs.DataQualityJobDefinitionDataQualityBaselineConfigConstraintsResource.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                statisticsResource = javaType.statisticsResource().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.sagemaker.kotlin.outputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResource.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/outputs/DataQualityJobDefinitionDataQualityBaselineConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property constraintsResource The constraints resource for a monitoring job. Fields are documented below.
 * @property statisticsResource The statistics resource for a monitoring job. Fields are documented below.
 */
public data class DataQualityJobDefinitionDataQualityBaselineConfig(
    public val constraintsResource: DataQualityJobDefinitionDataQualityBaselineConfigConstraintsResource? = null,
    public val statisticsResource: DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResource? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.sagemaker.outputs.DataQualityJobDefinitionDataQualityBaselineConfig): DataQualityJobDefinitionDataQualityBaselineConfig =
            DataQualityJobDefinitionDataQualityBaselineConfig(
                constraintsResource = javaType.constraintsResource().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.sagemaker.kotlin.outputs.DataQualityJobDefinitionDataQualityBaselineConfigConstraintsResource.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                statisticsResource = javaType.statisticsResource().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.sagemaker.kotlin.outputs.DataQualityJobDefinitionDataQualityBaselineConfigStatisticsResource.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
